#ifndef NT2_INCLUDE_FUNCTIONS_IDIVCEIL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IDIVCEIL_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/idivceil.hpp>

#endif
